@@ -261,7 +261,7 @@ module main
   assign myaxi_arprot = 0;
   assign myaxi_arqos = 0;
   assign myaxi_aruser = 0;
-  reg [32-1:0] outstanding_wreq_count_0;
+  reg [3-1:0] outstanding_wcount_0;
   assign myaxi_rready = 0;
   reg [32-1:0] fsm;
   localparam fsm_init = 0;
@@ -279,7 +279,7 @@ module main
 
   always @(posedge CLK) begin
     if(RST) begin
-      outstanding_wreq_count_0 <= 0;
+      outstanding_wcount_0 <= 0;
       myaxi_araddr <= 0;
       myaxi_arlen <= 0;
       myaxi_arvalid <= 0;
@@ -315,11 +315,11 @@ module main
         myaxi_wlast <= 0;
         last_4 <= 0;
       end 
-      if(myaxi_wlast && myaxi_wvalid && myaxi_wready && !(myaxi_bvalid && myaxi_bready)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 + 1;
+      if(myaxi_wlast && myaxi_wvalid && myaxi_wready && !(myaxi_bvalid && myaxi_bready) && (outstanding_wcount_0 < 7)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 + 1;
       end 
-      if(!(myaxi_wlast && myaxi_wvalid && myaxi_wready) && (myaxi_bvalid && myaxi_bready) && (outstanding_wreq_count_0 > 0)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 - 1;
+      if(!(myaxi_wlast && myaxi_wvalid && myaxi_wready) && (myaxi_bvalid && myaxi_bready) && (outstanding_wcount_0 > 0)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 - 1;
       end 
       myaxi_araddr <= 0;
       myaxi_arlen <= 0;
@@ -350,14 +350,14 @@ module main
       if(myaxi_awvalid && !myaxi_awready) begin
         myaxi_awvalid <= myaxi_awvalid;
       end 
-      if((fsm == 2) && ((counter_1 > 0) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0))) begin
+      if((fsm == 2) && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0))) begin
         myaxi_wdata <= wdata;
         myaxi_wvalid <= 1;
         myaxi_wlast <= 0;
         myaxi_wstrb <= { 4{ 1'd1 } };
         counter_1 <= counter_1 - 1;
       end 
-      if((fsm == 2) && ((counter_1 > 0) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0)) && (counter_1 == 1)) begin
+      if((fsm == 2) && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0)) && (counter_1 == 1)) begin
         myaxi_wlast <= 1;
         last_3 <= 1;
       end 
@@ -367,14 +367,14 @@ module main
         myaxi_wlast <= myaxi_wlast;
         last_3 <= last_3;
       end 
-      if((fsm == 20) && ((counter_2 > 0) && (myaxi_wready || !myaxi_wvalid) && (counter_2 > 0))) begin
+      if((fsm == 20) && ((counter_2 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_2 > 0))) begin
         myaxi_wdata <= wdata;
         myaxi_wvalid <= 1;
         myaxi_wlast <= 0;
         myaxi_wstrb <= { 4{ 1'd1 } };
         counter_2 <= counter_2 - 1;
       end 
-      if((fsm == 20) && ((counter_2 > 0) && (myaxi_wready || !myaxi_wvalid) && (counter_2 > 0)) && (counter_2 == 1)) begin
+      if((fsm == 20) && ((counter_2 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_2 > 0)) && (counter_2 == 1)) begin
         myaxi_wlast <= 1;
         last_4 <= 1;
       end 
@@ -426,7 +426,7 @@ module main
           end 
         end
         fsm_2: begin
-          if((counter_1 > 0) && (myaxi_wready || !myaxi_wvalid)) begin
+          if((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid)) begin
             wdata <= wdata + 1;
           end 
           if(last_3) begin
@@ -486,7 +486,7 @@ module main
           fsm <= fsm_20;
         end
         fsm_20: begin
-          if((counter_2 > 0) && (myaxi_wready || !myaxi_wvalid)) begin
+          if((counter_2 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid)) begin
             wdata <= wdata + 1;
           end 
           if(last_4) begin
